function gamma = fnrm_scale(A,Ainv,B,Binv,F,G,V,W)
%FNRM_SCALE
%
% Compute a scaling factor GAMMA so that the Frobenius norms
% of the matrices 
%
%        [ A  F*G ]           1    [ inv(A)  -inv(A)*F*G*inv(B) ]
% GAMMA* [        ]   and  ------- [                            ]   
%        [ 0   B  ]         GAMMA  [  0              inv(B)     ]
%
% are equlibrated.
%
% On input, A,Ainv contain A and its inverse, B,Binv contain B and its
% inverse, F,G contain the corresponding matrices, and V,W contain
% Ainv*F, G*Binv, respectively.
%
% Peter Benner, 2005-11-24.

n = size(A,1);
m = size(B,1);
p = size(F,2);
% need to check dimensions...

% c1 = || H ||_F
c1 = norm(A,'fro')^2 + norm(B,'fro')^2;
ZG = G*G';
ZF = F'*F;
d  = 0;
for j=1:p,
    d = d + ZG(j,:)*ZF(:,j);
end
c1 = sqrt(c1 + d);

% c2 = || inv(H) ||_F
c2 = norm(Ainv,'fro')^2 + norm(Binv,'fro')^2;
ZG = W*W';
ZF = V'*V;
d  = 0;
for j=1:p,
    d = d + ZG(j,:)*ZF(:,j);
end
c2 = sqrt(c2 + d);

gamma = sqrt(c2/c1);